Module http

Module http 

HTTP security header policy and shared auth scheme constants. HTTP security policy and auth vocabulary shared by transport adapters.

Structs

SecurityHeadersConfig
Secure-by-default response header configuration.

Enums

TransportSecurity
Transport security mode used when applying response headers.

Constants

BASIC_AUTH_SCHEME
HTTP Basic authentication scheme name.
BEARER_AUTH_SCHEME
HTTP Bearer authentication scheme name.